@@ -1,19 +1,38 @@
 
 # Imports
-from ..utils.io import *
-from ..utils.print import *
-from .utils import *
-from .shared_import import *
-from .book_optimizer import *
-from ..constants import *
+import stouputils as stp
+import os
+import shutil
+import json
+from PIL import Image
 from ..resource_pack.item_models import handle_item		# Handle new items models (used for the manual and the heavy workbench)
 from ..utils.database_helper import add_item_name_and_lore_if_missing
+from ..utils.ingredients import ingr_repr, ingr_to_id
+from ..utils.io import super_copy, write_all_files, super_merge_dict, delete_file, write_to_load_file
+from ..constants import CUSTOM_BLOCK_VANILLA, OVERRIDE_MODEL, RESULT_OF_CRAFTING, USED_FOR_CRAFTING, OFFICIAL_LIBS, CATEGORY, WIKI_COMPONENT
+from .shared_import import (
+	TEMPLATES_PATH, MANUAL_ASSETS_PATH, HEAVY_WORKBENCH_CATEGORY, FONT_FILE, SMALL_NONE_FONT,
+	MEDIUM_NONE_FONT, NONE_FONT, WIKI_INFO_FONT, VERY_SMALL_NONE_FONT, BORDER_COLOR, BORDER_SIZE,
+	HEAVY_WORKBENCH_CATEGORY, HOVER_EQUIVALENTS, WIKI_RESULT_OF_CRAFT_FONT, WIKI_INGR_OF_CRAFT_FONT,
+	WIKI_NONE_FONT, MICRO_NONE_FONT, SHAPED_3X3_FONT, SHAPED_2X2_FONT, INVISIBLE_ITEM_FONT, FURNACE_FONT,
+	PULVERIZING_FONT, HOVER_SHAPED_3X3_FONT, HOVER_SHAPED_2X2_FONT, HOVER_FURNACE_FONT, HOVER_PULVERIZING_FONT,
+	manual_pages, font_providers,
+	get_page_font, get_next_font, get_page_number
+)
+from .book_optimizer import optimize_element, remove_events
+from .iso_renders import generate_all_iso_renders
+from .image_utils import careful_resize, add_border, load_simple_case_no_border, generate_high_res_font
+from .book_components import get_item_component
+from .book_optimizer import optimize_element, remove_events
+from .page_font import generate_page_font, generate_wiki_font_for_ingr
+from .other_utils import generate_otherside_crafts, remove_unknown_crafts, convert_shapeless_to_shaped
+from .craft_content import generate_craft_content
 
 # Utility functions
 def deepcopy(x):
 	return json.loads(json.dumps(x))
 
-@measure_time(info, "Added manual to the database")
+@stp.measure_time(stp.info, "Added manual to the database")
 def main(config: dict):
 	# Copy everything in the manual assets folder to the templates folder
 	os.makedirs(TEMPLATES_PATH, exist_ok = True)
@@ -88,7 +107,7 @@ def routine(config: dict):
 
 	# If the manual cache is enabled and we have a cache file, load it
 	if config['cache_manual_pages'] and os.path.exists(config['manual_debug']) and os.path.exists(f"{config['manual_path']}/font/manual.json"):
-		with super_open(config['manual_debug'], "r") as f:
+		with stp.super_open(config['manual_debug'], "r") as f:
 			book_content = json.load(f)
 
 	# Else, generate all
@@ -99,7 +118,7 @@ def routine(config: dict):
 		for item, data in database.items():
 
 			if CATEGORY not in data:
-				suggestion(f"Item '{item}' has no category key. Skipping.")
+				stp.suggestion(f"Item '{item}' has no category key. Skipping.")
 				continue
 
 			category = data[CATEGORY]
@@ -109,7 +128,7 @@ def routine(config: dict):
 
 		# Error message if there is too many categories
 		if len(categories) > MAX_ITEMS_PER_PAGE:
-			error(f"Too many categories ({len(categories)}). Maximum is {MAX_ITEMS_PER_PAGE}. Please reduce the number of item categories.")
+			stp.error(f"Too many categories ({len(categories)}). Maximum is {MAX_ITEMS_PER_PAGE}. Please reduce the number of item categories.")
 
 		# Debug categories and sizes
 		s = ""
@@ -120,7 +139,7 @@ def routine(config: dict):
 			if len(items) > MAX_ITEMS_PER_PAGE:
 				s += f" (splitted into {len(items) // MAX_ITEMS_PER_PAGE + 1} pages)"
 		nb_categories: int = len(categories) - (1 if HEAVY_WORKBENCH_CATEGORY in categories else 0)
-		debug(f"Found {nb_categories} categories:{s}")
+		stp.debug(f"Found {nb_categories} categories:{s}")
 
 		# Split up categories into pages
 		categories_pages = {}
@@ -189,7 +208,7 @@ def routine(config: dict):
 					if os.path.exists(texture_path):
 						item_image = Image.open(texture_path)
 					else:
-						warning(f"Missing texture at '{texture_path}', using empty texture")
+						stp.warning(f"Missing texture at '{texture_path}', using empty texture")
 						item_image = Image.new("RGBA", (1, 1), (0, 0, 0, 0))
 					if not config['manual_high_resolution']:
 						resized = careful_resize(item_image, 32)
@@ -203,7 +222,7 @@ def routine(config: dict):
 					page_image.paste(resized, (x + 2, y + 2), mask)
 					x += simple_case.size[0]
 
-					# Add the clickEvent part to the line and add the 2 times the line if enough items
+					# Add the click_event part to the line and add the 2 times the line if enough items
 					component = get_item_component(config, item, only_those_components=["item_name", "custom_name"])
 					component["text"] = MEDIUM_NONE_FONT if not config['manual_high_resolution'] else high_res_font
 					line.append(component)
@@ -240,7 +259,7 @@ def routine(config: dict):
 				crafts += generate_otherside_crafts(config, name)
 				crafts = [craft for craft in crafts if craft["type"] not in ["blasting", "smoking", "campfire_cooking"]]	# Remove smelting dupes
 				crafts = remove_unknown_crafts(crafts)
-				crafts = unique_crafts(crafts)
+				crafts = stp.unique_list(crafts)
 
 				# If there are blue crafts, generate the content for the first craft
 				blue_crafts: list[dict] = [craft for craft in crafts if not craft.get("result")]
@@ -284,8 +303,14 @@ def routine(config: dict):
 						if (isinstance(wiki_component, dict) and "'" in wiki_component["text"]) \
 							or (isinstance(wiki_component, list) and any("'" in text["text"] for text in wiki_component)) \
 							or (isinstance(wiki_component, str) and "'" in wiki_component):
-							error(f"Wiki component for '{name}' should not contain single quotes are they fuck up the json files:\n{wiki_component}")
-						info_buttons.append({"text": WIKI_INFO_FONT + VERY_SMALL_NONE_FONT * 2, "hoverEvent": {"action": "show_text", "contents": raw_data[WIKI_COMPONENT]}})
+							stp.error(f"Wiki component for '{name}' should not contain single quotes are they fuck up the json files:\n{wiki_component}")
+						info_buttons.append({
+							"text": WIKI_INFO_FONT + VERY_SMALL_NONE_FONT * 2, 
+							"hover_event": {
+								"action": "show_text",
+								"value": raw_data[WIKI_COMPONENT]
+							}
+						})
 
 					# For each craft (except smelting dupes),
 					for i, craft in enumerate(crafts):
@@ -340,23 +365,32 @@ def routine(config: dict):
 
 						# Add the craft to the content
 						result_or_ingredient = WIKI_RESULT_OF_CRAFT_FONT if "result" not in craft else generate_wiki_font_for_ingr(config, name, craft)
-						info_buttons.append({"text": result_or_ingredient + VERY_SMALL_NONE_FONT * 2, "hoverEvent": {"action": "show_text", "contents": hover_text}})
+						info_buttons.append({
+							"text": result_or_ingredient + VERY_SMALL_NONE_FONT * 2, 
+							"hover_event": {
+								"action": "show_text",
+								"value": hover_text
+							}
+						})
 
-						# If there is a result to the craft, try to add the clickEvent that change to that page
+						# If there is a result to the craft, try to add the click_event that change to that page
 						if "result" in craft:
 							result_item = ingr_to_id(craft["result"], False)
 							if result_item in database:
-								info_buttons[-1]["clickEvent"] = {"action": "change_page", "value": str(get_page_number(result_item))}
+								info_buttons[-1]["click_event"] = {
+									"action": "change_page",
+									"page": get_page_number(result_item)
+								}
 				
 				# Add wiki buttons 5 by 5
 				if info_buttons:
 					
-					# If too many buttons, remove all the blue ones (no clickEvent) except the last one
+					# If too many buttons, remove all the blue ones (no click_event) except the last one
 					if len(info_buttons) > 15:
 						first_index: int = 0 if not raw_data.get(WIKI_COMPONENT) else 1
 						last_index: int = -1
 						for i, button in enumerate(info_buttons):
-							if isinstance(button, dict) and not button.get("clickEvent") and i != first_index:
+							if isinstance(button, dict) and not button.get("click_event") and i != first_index:
 								last_index = i
 						
 						# If there are more than 1 blue button, remove them except the last one
@@ -374,7 +408,7 @@ def routine(config: dict):
 							# Remove VERY_SMALL_NONE_FONT from last button to prevent automatic break line
 							content[-1]["text"] = content[-1]["text"].replace(VERY_SMALL_NONE_FONT, "")
 
-							# Re-add last 5 buttons (for good hoverEvent) but we replace the wiki font by the small font
+							# Re-add last 5 buttons (for good hover_event) but we replace the wiki font by the small font
 							content += ["\n"] + [x.copy() for x in content[-5:]]
 							for j in range(5):
 								content[-5 + j]["text"] = WIKI_NONE_FONT + VERY_SMALL_NONE_FONT * (2 if j != 4 else 0)
@@ -420,7 +454,7 @@ def routine(config: dict):
 				if os.path.exists(texture_path):
 					item_image = Image.open(texture_path)
 				else:
-					warning(f"Missing texture at '{texture_path}', using empty texture")
+					stp.warning(f"Missing texture at '{texture_path}', using empty texture")
 					item_image = Image.new("RGBA", (1, 1), (0, 0, 0, 0))
 				if not config['manual_high_resolution']:
 					resized = careful_resize(item_image, 32)
@@ -434,10 +468,10 @@ def routine(config: dict):
 				page_image.paste(resized, (x + 2, y + 2), mask)
 				x += simple_case.size[0]
 
-				# Add the clickEvent part to the line and add the 2 times the line if enough items
+				# Add the click_event part to the line and add the 2 times the line if enough items
 				component = get_item_component(config, item, ["item_name"])
-				component["hoverEvent"]["contents"]["components"]["item_name"] = str({"text": page["name"], "color": "white"})
-				component["clickEvent"]["value"] = str(page["number"])
+				component["hover_event"]["components"]["item_name"] = {"text": page["name"], "color": "white"}
+				component["click_event"]["page"] = page["number"]
 				if not config['manual_high_resolution']:
 					component["text"] = MEDIUM_NONE_FONT
 				else:
@@ -480,7 +514,7 @@ def routine(config: dict):
 		# Create the image and load Minecraft font
 		icon_path = f"{config['assets_folder']}/original_icon.png"
 		if not os.path.exists(icon_path):
-			error(f"Missing icon path at '{icon_path}' (needed for the manual)")
+			stp.error(f"Missing icon path at '{icon_path}' (needed for the manual)")
 		logo = Image.open(icon_path)
 		logo = careful_resize(logo, 256)
 
@@ -498,8 +532,8 @@ def routine(config: dict):
 		book_content.insert(0, intro_content)
 
 		## Optimize the book size
-		book_content_deepcopy: list[dict|list|str] = deepcopy(book_content)	# Deepcopy to avoid sharing same components (such as clickEvent)
-		book_content: list[dict|list|str] = list(optimize_book(book_content_deepcopy))
+		book_content_deepcopy: list[dict|list|str] = deepcopy(book_content)	# Deepcopy to avoid sharing same components (such as click_event)
+		book_content: list[dict|list|str] = list(optimize_element(book_content_deepcopy))
 
 		## Insert at 2nd page the heavy workbench
 		if "heavy_workbench" in database:
@@ -509,9 +543,9 @@ def routine(config: dict):
 			# Increase every change_page click event by 1
 			for page in book_content:
 				for component in page:
-					if isinstance(component, dict) and "clickEvent" in component and component["clickEvent"].get("action") == "change_page":
-						current_value: int = int(component["clickEvent"]["value"])
-						component["clickEvent"]["value"] = str(current_value + 1)
+					if isinstance(component, dict) and "click_event" in component and component["click_event"].get("action") == "change_page":
+						current_value: int = int(component["click_event"]["page"])
+						component["click_event"]["page"] = current_value + 1
 
 		# Add fonts
 		font_providers.append({"type":"bitmap","file":f"{namespace}:font/none.png", "ascent": 8, "height": 20, "chars": [NONE_FONT]})
@@ -534,13 +568,13 @@ def routine(config: dict):
 			font_providers.append({"type":"bitmap","file":f"{namespace}:font/furnace.png", "ascent": -3, "height": 58, "chars": [HOVER_FURNACE_FONT]})
 			font_providers.append({"type":"bitmap","file":f"{namespace}:font/pulverizing.png", "ascent": -3, "height": 58, "chars": [HOVER_PULVERIZING_FONT]})
 		fonts = {"providers": font_providers}
-		with super_open(f"{config['manual_path']}/font/manual.json", "w") as f:
-			f.write(super_json_dump(fonts).replace("\\\\", "\\"))
+		with stp.super_open(f"{config['manual_path']}/font/manual.json", "w") as f:
+			f.write(stp.super_json_dump(fonts))
 				
 		# Debug book_content
-		with super_open(config['manual_debug'], "w") as f:
-			f.write(super_json_dump(book_content))
-			debug(f"Debug book_content at '{config['manual_debug']}'")
+		with stp.super_open(config['manual_debug'], "w") as f:
+			f.write(stp.super_json_dump(book_content))
+			stp.debug(f"Debug book_content at '{config['manual_debug']}'")
 
 
 	# Copy the font provider and the generated textures to the resource pack
@@ -557,9 +591,9 @@ def routine(config: dict):
 			path: str = fp["file"]
 			path = path.replace(namespace + ':', f"{config['build_resource_pack']}/assets/{namespace}/textures/")
 			if not os.path.exists(path):
-				error(f"Missing font provider at '{path}' for {fp})")
+				stp.error(f"Missing font provider at '{path}' for {fp})")
 			if len(fp["chars"]) < 1 or (len(fp["chars"]) == 1 and not fp["chars"][0]):
-				error(f"Font provider '{path}' has no chars")
+				stp.error(f"Font provider '{path}' has no chars")
 
 	# Finally, prepend the manual to the database
 	manual_already_exists: bool = "manual" in database
@@ -569,7 +603,7 @@ def routine(config: dict):
 			"written_book_content": {
 				"title": config.get("manual_name", "Manual"),
 				"author": config['author'],
-				"pages": [str(i).replace("\\\\", "\\") for i in book_content],
+				"pages": book_content,
 			},
 			"item_model": f"{namespace}:manual",
 			"enchantment_glint_override": False,
